# Mapilio Calculation Library
[![Actions Status](https://github.com/mapilio/calculation/workflows/CI/badge.svg)](https://github.com/mapilio/calculation/actions)

## Git clone 
    git clone https://github.com/mapilio/calculation.git
## Installation
    pip install calculation-mapilio
##### or
    cd calculation
    python setup.py install --force
##### or
    cd calculation
    pip install -e .

# Documentation
Currently just the docstrings of the submodules and functions themselves, in [`numpydoc` format](https://numpydoc.readthedocs.io/en/latest/format.html).
